---
title: <span class="badge builder"></span> MapViewConfig
---
# <span class="badge builder"></span> MapViewConfig

## Constructor

```python
MapViewConfig()
```
## Methods

### <span class="badge object-method"></span> build

Builds the object.

```python
def build() -> geomap.MapViewConfig
```

### <span class="badge object-method"></span> all_layers

```python
def all_layers(all_layers: bool) -> typing.Self
```

### <span class="badge object-method"></span> id_val

```python
def id_val(id_val: str) -> typing.Self
```

### <span class="badge object-method"></span> last_only

```python
def last_only(last_only: bool) -> typing.Self
```

### <span class="badge object-method"></span> lat

```python
def lat(lat: int) -> typing.Self
```

### <span class="badge object-method"></span> layer

```python
def layer(layer: str) -> typing.Self
```

### <span class="badge object-method"></span> lon

```python
def lon(lon: int) -> typing.Self
```

### <span class="badge object-method"></span> max_zoom

```python
def max_zoom(max_zoom: int) -> typing.Self
```

### <span class="badge object-method"></span> min_zoom

```python
def min_zoom(min_zoom: int) -> typing.Self
```

### <span class="badge object-method"></span> padding

```python
def padding(padding: int) -> typing.Self
```

### <span class="badge object-method"></span> shared

```python
def shared(shared: bool) -> typing.Self
```

### <span class="badge object-method"></span> zoom

```python
def zoom(zoom: int) -> typing.Self
```

## See also

 * <span class="badge object-type-class"></span> [MapViewConfig](./object-MapViewConfig.md)
